package com.example;

import java.util.ArrayList;

import javax.ws.rs.core.Response;

import org.apache.cxf.endpoint.Server;
import org.apache.cxf.jaxrs.client.JAXRSClientFactory;
import org.apache.cxf.jaxrs.client.WebClient;
import org.apache.cxf.jaxrs.spring.JAXRSServerFactoryBeanDefinitionParser.SpringJAXRSServerFactoryBean;
import org.apache.cxf.transport.local.LocalConduit;
import org.jboss.weld.junit5.EnableWeld;
import org.jboss.weld.junit5.WeldInitiator;
import org.jboss.weld.junit5.WeldSetup;
import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.TestInstance;
import org.junit.jupiter.api.TestInstance.Lifecycle;

import com.fasterxml.jackson.jaxrs.json.JacksonJaxbJsonProvider;

@TestInstance(Lifecycle.PER_CLASS)
@EnableWeld
public class AccountApiTest {
	
	@WeldSetup
	private WeldInitiator weld = WeldInitiator.from(WeldInitiator.createWeld()
			.addPackages(com.example.AccountApi.class, com.example.service.impl.AccountApiServiceImpl.class)
			.addBeanClasses(com.example.app.RestApplication.class)
			.addBeanClasses(TestConfiguration.class)
			.addExtension(new org.apache.cxf.cdi.JAXRSCdiResourceExtension()))
	.build();

	private com.example.AccountApi api;

	@BeforeAll
	public void setup() throws Exception {
		api = JAXRSClientFactory.create(TestConfiguration.ENDPOINT_ADDRESS, com.example.AccountApi.class, TestConfiguration.defaultProviders());
		WebClient.getConfig(api).getRequestContext().put(LocalConduit.DIRECT_DISPATCH, Boolean.TRUE);
	}
	
	@Test
	public void addAccountParticipantsTest() {
		java.util.UUID accountId = null;

		Response response = this.api.addAccountParticipants(accountId);
		Assertions.assertNotNull(response);
		com.example.model.AddAccountParticipants200Response result = response.readEntity(com.example.model.AddAccountParticipants200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void addParticipantsToGroupTest() {
		java.util.UUID groupId = null;
		java.util.UUID accountId = null;

		Response response = this.api.addParticipantsToGroup(groupId, accountId);
		Assertions.assertNotNull(response);
	}

	@Test
	public void addUsersTest() {
		java.util.UUID accountId = null;

		Response response = this.api.addUsers(accountId);
		Assertions.assertNotNull(response);
	}

	@Test
	public void createGroupTest() {
		java.util.UUID accountId = null;

		Response response = this.api.createGroup(accountId);
		Assertions.assertNotNull(response);
		com.example.model.ParticipantGroup result = response.readEntity(com.example.model.ParticipantGroup.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void createSurveyTest() {
		java.util.UUID accountId = null;

		Response response = this.api.createSurvey(accountId);
		Assertions.assertNotNull(response);
		com.example.model.SurveyDetails result = response.readEntity(com.example.model.SurveyDetails.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void deleteAccountParticipantsTest() {
		java.util.UUID accountId = null;

		Response response = this.api.deleteAccountParticipants(accountId);
		Assertions.assertNotNull(response);
	}

	@Test
	public void deleteGroupTest() {
		java.util.UUID groupId = null;
		java.util.UUID accountId = null;

		Response response = this.api.deleteGroup(groupId, accountId);
		Assertions.assertNotNull(response);
	}

	@Test
	public void deleteSurveyResultsTest() {
		java.util.UUID accountId = null;
		java.util.UUID surveyId = null;

		Response response = this.api.deleteSurveyResults(accountId, surveyId);
		Assertions.assertNotNull(response);
	}

	@Test
	public void downloadAnonymisedSurveyReportTest() {
		java.util.UUID accountId = null;
		java.util.UUID surveyId = null;
		java.lang.String token = null;

		Response response = this.api.downloadAnonymisedSurveyReport(accountId, surveyId, token);
		Assertions.assertNotNull(response);
	}

	@Test
	public void getAccountTest() {
		java.util.UUID accountId = null;

		Response response = this.api.getAccount(accountId);
		Assertions.assertNotNull(response);
		com.example.model.AccountDetails result = response.readEntity(com.example.model.AccountDetails.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void getAccountParticipantsTest() {
		java.util.UUID accountId = null;
		java.lang.String cursor = null;
		com.example.model.SortParticipants sort = null;

		Response response = this.api.getAccountParticipants(accountId, cursor, sort);
		Assertions.assertNotNull(response);
		com.example.model.GetAccountParticipants200Response result = response.readEntity(com.example.model.GetAccountParticipants200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void getGroupParticipantsTest() {
		java.util.UUID groupId = null;
		java.util.UUID accountId = null;
		java.lang.String cursor = null;
		com.example.model.SortParticipants sort = null;

		Response response = this.api.getGroupParticipants(groupId, accountId, cursor, sort);
		Assertions.assertNotNull(response);
		com.example.model.GetGroupParticipants200Response result = response.readEntity(com.example.model.GetGroupParticipants200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void getGroupsTest() {
		java.util.UUID accountId = null;

		Response response = this.api.getGroups(accountId);
		Assertions.assertNotNull(response);
		java.util.List&lt;com.example.model.ParticipantGroup&gt; result = response.readEntity(java.util.List.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void getReportsTest() {
		java.util.UUID accountId = null;
		java.lang.String cursor = null;
		com.example.model.SortSurveys sort = null;

		Response response = this.api.getReports(accountId, cursor, sort);
		Assertions.assertNotNull(response);
		com.example.model.GetReports200Response result = response.readEntity(com.example.model.GetReports200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void getSurveysTest() {
		java.util.UUID accountId = null;
		java.lang.String cursor = null;
		com.example.model.SortSurveys sort = null;
		java.util.List&lt;com.example.model.FilterSurveys&gt; filter = null;

		Response response = this.api.getSurveys(accountId, cursor, sort, filter);
		Assertions.assertNotNull(response);
		com.example.model.GetSurveys200Response result = response.readEntity(com.example.model.GetSurveys200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void getSurveyTemplatesTest() {
		java.util.UUID accountId = null;

		Response response = this.api.getSurveyTemplates(accountId);
		Assertions.assertNotNull(response);
		java.util.List&lt;com.example.model.SurveyTemplate&gt; result = response.readEntity(java.util.List.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void getTopicsTest() {
		java.util.UUID accountId = null;

		Response response = this.api.getTopics(accountId);
		Assertions.assertNotNull(response);
		com.example.model.GetTopics200Response result = response.readEntity(com.example.model.GetTopics200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void getUsersTest() {
		java.util.UUID accountId = null;
		java.lang.String cursor = null;

		Response response = this.api.getUsers(accountId, cursor);
		Assertions.assertNotNull(response);
		com.example.model.GetUsers200Response result = response.readEntity(com.example.model.GetUsers200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void patchAccountTest() {
		java.util.UUID accountId = null;

		Response response = this.api.patchAccount(accountId);
		Assertions.assertNotNull(response);
		com.example.model.AccountDetails result = response.readEntity(com.example.model.AccountDetails.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void patchAccountParticipantTest() {
		java.util.UUID accountId = null;
		java.util.UUID participantId = null;

		Response response = this.api.patchAccountParticipant(accountId, participantId);
		Assertions.assertNotNull(response);
		com.example.model.Participant result = response.readEntity(com.example.model.Participant.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void patchGroupTest() {
		java.util.UUID groupId = null;
		java.util.UUID accountId = null;

		Response response = this.api.patchGroup(groupId, accountId);
		Assertions.assertNotNull(response);
		com.example.model.ParticipantGroup result = response.readEntity(com.example.model.ParticipantGroup.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void removeGroupParticipantsTest() {
		java.util.UUID groupId = null;
		java.util.UUID accountId = null;

		Response response = this.api.removeGroupParticipants(groupId, accountId);
		Assertions.assertNotNull(response);
	}

	@Test
	public void removeUserTest() {
		java.util.UUID accountId = null;
		java.util.UUID userId = null;

		Response response = this.api.removeUser(accountId, userId);
		Assertions.assertNotNull(response);
	}

	@Test
	public void requestAnonymisedSurveyReportDownloadTest() {
		java.util.UUID accountId = null;
		java.util.UUID surveyId = null;

		Response response = this.api.requestAnonymisedSurveyReportDownload(accountId, surveyId);
		Assertions.assertNotNull(response);
		com.example.model.RequestAnonymisedSurveyReportDownload200Response result = response.readEntity(com.example.model.RequestAnonymisedSurveyReportDownload200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void searchParticipantsTest() {
		java.util.UUID accountId = null;
		java.lang.String query = null;
		java.lang.String cursor = null;
		com.example.model.SortParticipants sort = null;
		java.util.UUID group = null;

		Response response = this.api.searchParticipants(accountId, query, cursor, sort, group);
		Assertions.assertNotNull(response);
		com.example.model.SearchParticipants200Response result = response.readEntity(com.example.model.SearchParticipants200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void updateUserTest() {
		java.util.UUID accountId = null;
		java.util.UUID userId = null;

		Response response = this.api.updateUser(accountId, userId);
		Assertions.assertNotNull(response);
		com.example.model.UserDetails result = response.readEntity(com.example.model.UserDetails.class);
		Assertions.assertNotNull(result);
	}

}
