package com.example;

import java.util.ArrayList;

import javax.ws.rs.core.Response;

import org.apache.cxf.endpoint.Server;
import org.apache.cxf.jaxrs.client.JAXRSClientFactory;
import org.apache.cxf.jaxrs.client.WebClient;
import org.apache.cxf.jaxrs.spring.JAXRSServerFactoryBeanDefinitionParser.SpringJAXRSServerFactoryBean;
import org.apache.cxf.transport.local.LocalConduit;
import org.jboss.weld.junit5.EnableWeld;
import org.jboss.weld.junit5.WeldInitiator;
import org.jboss.weld.junit5.WeldSetup;
import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.TestInstance;
import org.junit.jupiter.api.TestInstance.Lifecycle;

import com.fasterxml.jackson.jaxrs.json.JacksonJaxbJsonProvider;

@TestInstance(Lifecycle.PER_CLASS)
@EnableWeld
public class PersonApiTest {
	
	@WeldSetup
	private WeldInitiator weld = WeldInitiator.from(WeldInitiator.createWeld()
			.addPackages(com.example.PersonApi.class, com.example.service.impl.PersonApiServiceImpl.class)
			.addBeanClasses(com.example.app.RestApplication.class)
			.addBeanClasses(TestConfiguration.class)
			.addExtension(new org.apache.cxf.cdi.JAXRSCdiResourceExtension()))
	.build();

	private com.example.PersonApi api;

	@BeforeAll
	public void setup() throws Exception {
		api = JAXRSClientFactory.create(TestConfiguration.ENDPOINT_ADDRESS, com.example.PersonApi.class, TestConfiguration.defaultProviders());
		WebClient.getConfig(api).getRequestContext().put(LocalConduit.DIRECT_DISPATCH, Boolean.TRUE);
	}
	
	@Test
	public void confirmTotpTest() {

		Response response = this.api.confirmTotp();
		Assertions.assertNotNull(response);
	}

	@Test
	public void getMyDetailsTest() {

		Response response = this.api.getMyDetails();
		Assertions.assertNotNull(response);
		com.example.model.PersonDetails result = response.readEntity(com.example.model.PersonDetails.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void startTotpTest() {

		Response response = this.api.startTotp();
		Assertions.assertNotNull(response);
		com.example.model.StartTotp200Response result = response.readEntity(com.example.model.StartTotp200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void updateMyDetailsTest() {

		Response response = this.api.updateMyDetails();
		Assertions.assertNotNull(response);
		com.example.model.PersonDetails result = response.readEntity(com.example.model.PersonDetails.class);
		Assertions.assertNotNull(result);
	}

}
