package com.example;

import java.util.ArrayList;

import javax.ws.rs.core.Response;

import org.apache.cxf.endpoint.Server;
import org.apache.cxf.jaxrs.client.JAXRSClientFactory;
import org.apache.cxf.jaxrs.client.WebClient;
import org.apache.cxf.jaxrs.spring.JAXRSServerFactoryBeanDefinitionParser.SpringJAXRSServerFactoryBean;
import org.apache.cxf.transport.local.LocalConduit;
import org.jboss.weld.junit5.EnableWeld;
import org.jboss.weld.junit5.WeldInitiator;
import org.jboss.weld.junit5.WeldSetup;
import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.TestInstance;
import org.junit.jupiter.api.TestInstance.Lifecycle;

import com.fasterxml.jackson.jaxrs.json.JacksonJaxbJsonProvider;

@TestInstance(Lifecycle.PER_CLASS)
@EnableWeld
public class SurveyApiTest {
	
	@WeldSetup
	private WeldInitiator weld = WeldInitiator.from(WeldInitiator.createWeld()
			.addPackages(com.example.SurveyApi.class, com.example.service.impl.SurveyApiServiceImpl.class)
			.addBeanClasses(com.example.app.RestApplication.class)
			.addBeanClasses(TestConfiguration.class)
			.addExtension(new org.apache.cxf.cdi.JAXRSCdiResourceExtension()))
	.build();

	private com.example.SurveyApi api;

	@BeforeAll
	public void setup() throws Exception {
		api = JAXRSClientFactory.create(TestConfiguration.ENDPOINT_ADDRESS, com.example.SurveyApi.class, TestConfiguration.defaultProviders());
		WebClient.getConfig(api).getRequestContext().put(LocalConduit.DIRECT_DISPATCH, Boolean.TRUE);
	}
	
	@Test
	public void addGroupsTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.addGroups(surveyId);
		Assertions.assertNotNull(response);
	}

	@Test
	public void addParticipantsTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.addParticipants(surveyId);
		Assertions.assertNotNull(response);
		com.example.model.AddParticipants200Response result = response.readEntity(com.example.model.AddParticipants200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void closeSurveyTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.closeSurvey(surveyId);
		Assertions.assertNotNull(response);
		com.example.model.SurveyDetails result = response.readEntity(com.example.model.SurveyDetails.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void createCustomQuestionTest() {
		java.util.UUID surveyId = null;
		java.util.UUID sectionId = null;

		Response response = this.api.createCustomQuestion(surveyId, sectionId);
		Assertions.assertNotNull(response);
		com.example.model.SurveySection result = response.readEntity(com.example.model.SurveySection.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void createPreviewTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.createPreview(surveyId);
		Assertions.assertNotNull(response);
		com.example.model.CreatePreview200Response result = response.readEntity(com.example.model.CreatePreview200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void deleteSurveyTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.deleteSurvey(surveyId);
		Assertions.assertNotNull(response);
	}

	@Test
	public void downloadReportTest() {
		java.util.UUID surveyId = null;
		java.lang.String token = null;
		java.lang.String frontend = null;

		Response response = this.api.downloadReport(surveyId, token, frontend);
		Assertions.assertNotNull(response);
	}

	@Test
	public void getCustomSectionTest() {
		java.util.UUID surveyId = null;
		java.util.UUID sectionId = null;

		Response response = this.api.getCustomSection(surveyId, sectionId);
		Assertions.assertNotNull(response);
		com.example.model.SurveySection result = response.readEntity(com.example.model.SurveySection.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void getFiltersTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.getFilters(surveyId);
		Assertions.assertNotNull(response);
		com.example.model.GetFilters200Response result = response.readEntity(com.example.model.GetFilters200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void getGroupsTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.getGroups(surveyId);
		Assertions.assertNotNull(response);
		com.example.model.GetGroups200Response result = response.readEntity(com.example.model.GetGroups200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void getParticipationsTest() {
		java.util.UUID surveyId = null;
		java.lang.String cursor = null;
		com.example.model.SortParticipants sort = null;
		java.util.List&lt;com.example.model.FilterSurveyParticipants&gt; filter = null;
		java.util.List&lt;java.util.UUID&gt; groups = null;

		Response response = this.api.getParticipations(surveyId, cursor, sort, filter, groups);
		Assertions.assertNotNull(response);
		com.example.model.SurveyParticipationsResponse result = response.readEntity(com.example.model.SurveyParticipationsResponse.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void getReportTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.getReport(surveyId);
		Assertions.assertNotNull(response);
		com.example.model.GetReport200Response result = response.readEntity(com.example.model.GetReport200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void getSurveyTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.getSurvey(surveyId);
		Assertions.assertNotNull(response);
		com.example.model.SurveyDetails result = response.readEntity(com.example.model.SurveyDetails.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void openSurveyTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.openSurvey(surveyId);
		Assertions.assertNotNull(response);
		com.example.model.SurveyDetails result = response.readEntity(com.example.model.SurveyDetails.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void patchSurveyTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.patchSurvey(surveyId);
		Assertions.assertNotNull(response);
		com.example.model.SurveyDetails result = response.readEntity(com.example.model.SurveyDetails.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void patchSurveyReportTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.patchSurveyReport(surveyId);
		Assertions.assertNotNull(response);
		com.example.model.PatchSurveyReport200Response result = response.readEntity(com.example.model.PatchSurveyReport200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void postRemindersTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.postReminders(surveyId);
		Assertions.assertNotNull(response);
		com.example.model.PostReminders200Response result = response.readEntity(com.example.model.PostReminders200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void removeGroupsTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.removeGroups(surveyId);
		Assertions.assertNotNull(response);
	}

	@Test
	public void removeParticipationsTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.removeParticipations(surveyId);
		Assertions.assertNotNull(response);
	}

	@Test
	public void removeQuestionTest() {
		java.util.UUID surveyId = null;
		java.util.UUID sectionId = null;
		java.util.UUID questionId = null;

		Response response = this.api.removeQuestion(surveyId, sectionId, questionId);
		Assertions.assertNotNull(response);
	}

	@Test
	public void requestReportDownloadTest() {
		java.util.UUID surveyId = null;

		Response response = this.api.requestReportDownload(surveyId);
		Assertions.assertNotNull(response);
		com.example.model.RequestReportDownload200Response result = response.readEntity(com.example.model.RequestReportDownload200Response.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void resetCustomSectionTest() {
		java.util.UUID surveyId = null;
		java.util.UUID sectionId = null;

		Response response = this.api.resetCustomSection(surveyId, sectionId);
		Assertions.assertNotNull(response);
		com.example.model.SurveySection result = response.readEntity(com.example.model.SurveySection.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void searchParticipationsTest() {
		java.util.UUID surveyId = null;
		java.lang.String query = null;
		java.lang.String cursor = null;
		com.example.model.SortParticipants sort = null;
		java.util.List&lt;com.example.model.FilterSurveyParticipants&gt; filter = null;
		java.util.List&lt;java.util.UUID&gt; groups = null;

		Response response = this.api.searchParticipations(surveyId, query, cursor, sort, filter, groups);
		Assertions.assertNotNull(response);
		com.example.model.SurveyParticipationsResponse result = response.readEntity(com.example.model.SurveyParticipationsResponse.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void setCustomQuestionsTest() {
		java.util.UUID surveyId = null;
		java.util.UUID sectionId = null;

		Response response = this.api.setCustomQuestions(surveyId, sectionId);
		Assertions.assertNotNull(response);
		com.example.model.SurveySection result = response.readEntity(com.example.model.SurveySection.class);
		Assertions.assertNotNull(result);
	}

	@Test
	public void updateCustomQuestionTest() {
		java.util.UUID surveyId = null;
		java.util.UUID sectionId = null;
		java.util.UUID questionId = null;

		Response response = this.api.updateCustomQuestion(surveyId, sectionId, questionId);
		Assertions.assertNotNull(response);
		com.example.model.Question result = response.readEntity(com.example.model.Question.class);
		Assertions.assertNotNull(result);
	}

}
